@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Tobias Koenig <tokoe@kde.org>                   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef FICTIONBOOK_CONVERTER_H
 #define FICTIONBOOK_CONVERTER_H
@@ -74,7 +71,7 @@ private:
     class DocumentInfo;
     DocumentInfo *mDocumentInfo;
 
-    int mSectionCounter;
+    int mSectionCounter = 0;
 
     QMap<QString, QTextBlock> mSectionMap;
     QMap<QString, QPair<int, int>> mLocalLinks;
